@@ -10,15 +10,15 @@ class HOTP(OTP):
         @returns [Integer] OTP
         """
         return self.generate_otp(count)
-    
+
     def verify(self, otp, counter):
         """
         Verifies the OTP passed in against the current time OTP
         @param [String/Integer] otp the OTP to check against
         @param [Integer] counter the counter of the OTP
         """
-        return otp == self.at(counter)
-    
+        return unicode(otp) == unicode(self.at(counter))
+
     def provisioning_uri(self, name, initial_count=0):
         """
         Returns the provisioning URI for the OTP
